//
//  BLEDeviceViewController.h
//  HMSoft
//
//  Created by IMJUN on 7/13/12.
//  Copyright (c) 2015 jnhuamao.cn. All rights reserved.
//

#import "BLEViewController.h"

@interface BLEViewController(){
    
}
@property (strong, nonatomic) SerialGATT *sensor;
@property (nonatomic, retain) NSMutableArray *devices;
@property (nonatomic,strong) UIActivityIndicatorView *indicator;

@end

@implementation BLEViewController


-(instancetype)initWithStyle:(UITableViewStyle)style
{
    return [super initWithStyle:UITableViewStyleGrouped];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.sensor = [[SerialGATT alloc] init];
    self.sensor.delegate = self;
    [self.sensor setup];
    self.devices = [[NSMutableArray alloc]init];
    [NSTimer scheduledTimerWithTimeInterval:2 target:self selector:@selector(scanTimer) userInfo:nil repeats:NO];
    self.title = @"Select BLE Device";
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc]initWithTitle:@"Back" style:UIBarButtonItemStylePlain target:self action:@selector(onBack)];
    _indicator = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    self.tableView.rowHeight = 50.f;
    _indicator.hidesWhenStopped = YES;
    _indicator.center = self.view.center;
    [self.view addSubview:_indicator];
    [_indicator startAnimating];
}

-(void)onBack{
    [self.sensor stopScan];
    self.sensor.peripherals = nil;
    self.sensor.delegate = nil;
    [_indicator stopAnimating];
//    [self.navigationController popViewControllerAnimated:YES];
    [self dismissViewControllerAnimated:YES completion:nil];
}


- (void)scanHMSoftDevices {
    if ([self.sensor activePeripheral]) {
        if (self.sensor.activePeripheral.state == CBPeripheralStateConnected) {
            [self.sensor.manager cancelPeripheralConnection:self.sensor.activePeripheral];
            self.sensor.activePeripheral = nil;
        }
    }
    if ([self.sensor peripherals]) {
        self.sensor.peripherals = nil;
        [self.devices removeAllObjects];
        [self.tableView reloadData];
    }
    [self.sensor findHMSoftPeripherals:5];
}

-(void)scanTimer
{
     [self scanHMSoftDevices];
}

-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.devices count];
}

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    [self.sensor stopScan];
    CBPeripheral *dev = self.devices[indexPath.row];
    [self.delegate didSelectDevice:dev sensor:self.sensor];
    [self dismissViewControllerAnimated:YES completion:nil];
}

-(UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    static NSString *cellId = @"peripheral";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellId];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellId];
    }
    CBPeripheral *dev = self.devices[indexPath.row];
    NSUserDefaults *user = [NSUserDefaults standardUserDefaults];
    NSString *displayName = [user objectForKey:dev.name];
    if(displayName==nil || [displayName isEqualToString:@""]){
       cell.textLabel.text = dev.name;
    }else{
        cell.textLabel.text = displayName;
    }
    
    cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    return cell;
}

-(void)setDisconnect{
    [_indicator stopAnimating];
}

-(void) peripheralFound:(CBPeripheral *)peripheral
{
    [_indicator stopAnimating];
    NSString *name = peripheral.name;
    if(name ==nil || [name isEqualToString:@""]) return;
    [self.devices addObject:peripheral];
    [self.tableView reloadData];
}

-(void)setConnectTimeOut
{
    [_indicator stopAnimating];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [self.navigationController setNavigationBarHidden:NO animated:YES];
}
@end
